Trait WeakPtrTarget

unsafe trait WeakPtrTarget

Trait bound for types which may be used as the T inside of a WeakPtr<T> in generic code.

This trait has no publicly callable or implementable methods. Implementing it outside of the CXX codebase is not supported.

Implementors