Trait UniquePtrTarget
unsafe trait UniquePtrTarget
Trait bound for types which may be used as the T inside of a
UniquePtr<T> in generic code.
This trait has no publicly callable or implementable methods. Implementing it outside of the CXX codebase is not supported.
Example
A bound T: UniquePtrTarget may be necessary when manipulating
UniquePtr in generic code.
use ;
use Display;
Writing the same generic function without a UniquePtrTarget trait bound
would not compile.